Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/editors/interface/interface_icons.c')
-rw-r--r--source/blender/editors/interface/interface_icons.c11
1 files changed, 4 insertions, 7 deletions
diff --git a/source/blender/editors/interface/interface_icons.c b/source/blender/editors/interface/interface_icons.c
index c1418c5b6e8..39f6cb7b0c2 100644
--- a/source/blender/editors/interface/interface_icons.c
+++ b/source/blender/editors/interface/interface_icons.c
@@ -1,6 +1,4 @@
/*
- * $Id$
- *
* ***** BEGIN GPL LICENSE BLOCK *****
*
* This program is free software; you can redistribute it and/or
@@ -47,7 +45,6 @@
#include "BLI_math.h"
#include "BLI_blenlib.h"
-#include "BLI_storage_types.h"
#include "BLI_utildefines.h"
#include "DNA_brush_types.h"
@@ -609,11 +606,11 @@ static void init_iconfile_list(struct ListBase *list)
if(icondir==NULL)
return;
/* since BLI_getdir changes the current working directory, restore it
back to old value afterwards */
- if(!BLI_getwdN(olddir, sizeof(olddir)))
+ if(!BLI_current_working_dir(olddir, sizeof(olddir)))
restoredir = 0;
- totfile = BLI_getdir(icondir, &dir);
+ totfile = BLI_dir_contents(icondir, &dir);
if (restoredir && !chdir(olddir)) {} /* fix warning about checking return value */
for(i=0; i<totfile; i++) {
@@ -662,7 +659,7 @@ static void init_iconfile_list(struct ListBase *list)
}
}
- /* free temporary direntry structure that's been created by BLI_getdir() */
+ /* free temporary direntry structure that's been created by BLI_dir_contents() */
i= totfile-1;
for(; i>=0; i--){
@@ -609,11 +606,11 @@ static void init_iconfile_list(struct ListBase *list)
if(icondir==NULL)
return;
- /* since BLI_getdir changes the current working directory, restore it
+ /* since BLI_dir_contents changes the current working directory, restore it
back to old value afterwards */